from enum import Enum

class Voices(Enum):
    SILVAN = "voices/silvan.voicex"
    GABBY = "voices/gabby.voicex"
    GRANNY = "voices/granny.voicex"
    KIMBERLY = "voices/kimberly.voicex"
    ELISABETH = "voices/drw_female_1.voicex"
    LISA = "voices/lisa_old.voicex"
    DRW_FEMALE_1 = "voices/drw_female_1.voicex"
    DRW_FEMALE_2 = "voices/drw_female_2.voicex"
    DRW_FEMALE_3 = "voices/drw_female_3.voicex"
    MALE_DEPRESSED = "voices/male_depressed.voicex"
    MALE_SHY_1 = "voices/male_shy_1.voicex"
    MALE_SHY_2 = "voices/male_shy_2.voicex"
    LENNY = "voices/lenny.voicex"
    ANDREA = "voices/andrea.voicex"
